import { Directive, Input, ElementRef, ViewContainerRef, Injector, HostListener, ComponentFactoryResolver } from '@angular/core';
import { PositionService } from '../../tool/pos.service';
import { Resize } from '../../service/resize.service';
import { TooltipComponent } from './tooltip.component';
import { GlobService } from '../../service/glob.service';
var TooltipDirective = (function () {
    function TooltipDirective(_el, _cfr, _vcr, injector, _pos, _res, glob) {
        var _this = this;
        this._el = _el;
        this._cfr = _cfr;
        this._vcr = _vcr;
        this.injector = injector;
        this._pos = _pos;
        this._res = _res;
        this.glob = glob;
        this.placement = 'top';
        this.showStyle = this.glob.tooltip.showStyle;
        this.hidStyle = this.glob.tooltip.hidStyle;
        this.resSub = _res.valSub.subscribe(function () { return _this.node = null; });
    }
    Object.defineProperty(TooltipDirective.prototype, "tipValue", {
        set: function (val) {
            this.value = val;
            this.reset();
        },
        enumerable: true,
        configurable: true
    });
    ;
    TooltipDirective.prototype.mouseenter = function () {
        !this.preventDefault && this.open();
    };
    TooltipDirective.prototype.mouseleave = function () {
        !this.preventDefault && this.close();
    };
    TooltipDirective.prototype.onceShow = function (val) {
        this.onceValue = val;
        this.onceNum = 2;
        this.reset();
    };
    TooltipDirective.prototype.reset = function () {
        if (this.node) {
            this.close();
            this.node = null;
            this.open();
        }
    };
    TooltipDirective.prototype.open = function () {
        var nodes, body = document.body, val = this.value;
        if (this.onceNum) {
            this.onceNum--;
            this.node = null;
            if (this.onceNum)
                val = this.onceValue;
        }
        if (this.node) {
            body.appendChild(this.node);
            this.anTool.state = 'start';
        }
        else {
            if (typeof val == 'string') {
                var node_1 = document.createElement('span');
                node_1.innerText = val;
                nodes = [node_1];
            }
            else {
                var viewRef = this._vcr.createEmbeddedView(val);
                nodes = viewRef.rootNodes;
            }
            var componentFactory = this._cfr.resolveComponentFactory(TooltipComponent);
            var componentRef = this._vcr.createComponent(componentFactory, 0, this.injector, [nodes]);
            var node = this.node = componentRef.location.nativeElement;
            this.anTool = new this.glob.tool.voidAnimate({
                node: node,
                start: this.hidStyle,
                end: this.showStyle
            });
            componentRef.instance.pure = this.pure;
            if (!this.pure)
                node.classList.add('tip');
            body.appendChild(node);
            this.anTool.state = 'start';
            var result = this._pos.tooltipPos(this._el.nativeElement, node, this.placement);
            for (var i in result.pos) {
                node.style[i] = result.pos[i];
            }
            componentRef.instance.Arrow = { placement: this.placement, dis: result.dis };
        }
    };
    TooltipDirective.prototype.close = function () {
        this.anTool.state = 'end';
    };
    TooltipDirective.prototype.ngOnDestroy = function () {
        this.resSub.unsubscribe();
    };
    TooltipDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[ngz-tooltip]',
                    exportAs: 'ngzTooltip'
                },] },
    ];
    /** @nocollapse */
    TooltipDirective.ctorParameters = function () { return [
        { type: ElementRef, },
        { type: ComponentFactoryResolver, },
        { type: ViewContainerRef, },
        { type: Injector, },
        { type: PositionService, },
        { type: Resize, },
        { type: GlobService, },
    ]; };
    TooltipDirective.propDecorators = {
        'placement': [{ type: Input },],
        'tipValue': [{ type: Input, args: ['ngz-tooltip',] },],
        'pure': [{ type: Input },],
        'preventDefault': [{ type: Input },],
        'mouseenter': [{ type: HostListener, args: ['mouseenter',] },],
        'mouseleave': [{ type: HostListener, args: ['mouseleave',] },],
        'showStyle': [{ type: Input },],
        'hidStyle': [{ type: Input },],
    };
    return TooltipDirective;
}());
export { TooltipDirective };
//# sourceMappingURL=tooltip.directive.js.map