import { Directive, Input, ElementRef, Output, EventEmitter } from '@angular/core';
import { Resize } from '../service/resize.service';
import { ScrollService } from '../service/scroll.service';
import { ToolService } from '../tool/tool.service';
var StickyBlockDirective = (function () {
    function StickyBlockDirective(res, _scroll, el, tool) {
        this.res = res;
        this._scroll = _scroll;
        this.el = el;
        this.tool = tool;
        this.top = 0;
        this.state = new EventEmitter();
    }
    StickyBlockDirective.prototype.cal = function () {
        var pos = this._scroll.pos.getPos(this.self);
        var parentPos = this._scroll.pos.getPos(this.parent);
        this.stickyTop = pos.top - this.top;
        this.stickyBottom = parentPos.top + this.parent.clientHeight - pos.h - this.top;
    };
    StickyBlockDirective.prototype.setSticky = function () {
        var _this = this;
        var self = this.self;
        setTimeout(function () {
            _this.cal();
            var setBlock = function (v) {
                if (v.top > _this.stickyBottom) {
                    self.style.position = 'absolute';
                    self.style.bottom = 0;
                    self.style.top = null;
                }
                else if (v.top > _this.stickyTop) {
                    self.style.position = 'fixed';
                    self.style.top = _this.top + 'px';
                }
                else {
                    self.style.position = null;
                    self.style.top = null;
                }
            };
            setBlock(_this._scroll.getPos());
            _this.destroy();
            _this.scrollSub = _this._scroll.scrollEvent.subscribe(function (v) { return setBlock(v); });
        }, 1);
    };
    StickyBlockDirective.prototype.ngOnInit = function () {
        this.self = this.el.nativeElement;
        this.parent = this.self.parentElement;
        var style = window.getComputedStyle(this.self, null);
        if (!this.useJs && style.position.match(/sticky/)) {
            this.state.emit('css');
            return this.self.style.top = this.top + 'px';
        }
        this._scroll.pos.posToRel(this.parent);
        this.state.emit('js');
        this.setSticky();
    };
    StickyBlockDirective.prototype.destroy = function () {
        this.scrollSub && this.scrollSub.unsubscribe();
    };
    StickyBlockDirective.prototype.ngOnDestroy = function () {
        this.destroy();
    };
    StickyBlockDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[ngz-sticky]',
                    host: {
                        'class': 'sticky'
                    },
                    exportAs: 'sticky-block'
                },] },
    ];
    /** @nocollapse */
    StickyBlockDirective.ctorParameters = function () { return [
        { type: Resize, },
        { type: ScrollService, },
        { type: ElementRef, },
        { type: ToolService, },
    ]; };
    StickyBlockDirective.propDecorators = {
        'top': [{ type: Input },],
        'useJs': [{ type: Input },],
        'state': [{ type: Output },],
    };
    return StickyBlockDirective;
}());
export { StickyBlockDirective };
//# sourceMappingURL=sticky-block.directive.js.map